<?php

namespace Drupal\webform_paystack_field\Element;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Render\Element;
use Drupal\Core\Render\Element\Textfield;

/**
 * The form element.
 *
 * @FormElement("webform_webform_paystack_field")
 */
class WebformPaystackFieldWebformElement extends Textfield {

  /**
   * {@inheritdoc}
   */
  public function getInfo() {
    $class = static::class;
    return [
      '#input' => TRUE,
      '#size' => 60,
      '#maxlength' => 128,
      '#autocomplete_route_name' => FALSE,
      '#process' => [
        [$class, 'processTextField'],
        [$class, 'processAutocomplete'],
        [$class, 'processAjaxForm'],
        [$class, 'processPattern'],
        [$class, 'processGroup'],
      ],
      '#pre_render' => [
        [$class, 'preRenderTextfield'],
        [$class, 'preRenderGroup'],
      ],
      '#theme' => 'input__textfield',
      '#theme_wrappers' => ['form_element'],
    ];
  }

  /**
   * {@inheritdoc}
   */
  public static function valueCallback(&$element, $input, FormStateInterface $form_state) {
    if ($input !== FALSE && $input !== NULL) {
      // This should be a string, but allow other scalars since they might be
      // valid input in programmatic form submissions.
      if (!is_scalar($input)) {
        $input = '';
      }
      return str_replace(["\r", "\n"], '', $input);
    }
    return NULL;
  }

  /**
   * {@inheritdoc}
   */
  public static function processTextField(&$element, FormStateInterface $form_state, &$complete_form) {

    $config = \Drupal::config('webform_paystack_field.settings');
    if ($config->get('webform_paystack_field_within_website') == TRUE) {
      $element['#attached']['library'][] = 'webform_paystack_field/webform_paystack_field';
      $element['#attached']['drupalSettings']['paystack_key'] = $config->get('webform_paystack_field_public_key');
      $element['#attached']['drupalSettings']['success_message'] = $config->get('webform_paystack_field_success_message') ?? t('Thank you for your payment.');
      $element['#attached']['drupalSettings']['edit_amount'] = $element['#id'];
      $element['#attached']['drupalSettings']['form_id'] = $complete_form['#id'];
      $element['#attached']['drupalSettings']['subaccount_id'] = $element['#webform_paystack_field_subaccount_id'] ?? '';
    }
    $element['#attached']['library'][] = 'webform_paystack_field/webform_paystack_field_custom';
    return $element;
  }

  /**
   * Prepares a #type 'textfield' render element for input.html.twig.
   *
   * @param array $element
   *   An associative array containing the properties of the element.
   *   Properties used: #title, #value, #description, #size, #maxlength,
   *   #placeholder, #required, #attributes.
   *
   * @return array
   *   The $element with prepared variables ready for input.html.twig.
   */
  public static function preRenderTextfield($element) {
    $element['#attributes']['type'] = 'text';
    Element::setAttributes($element, ['id', 'name', 'value', 'size', 'maxlength', 'placeholder']);
    static::setAttributes($element, ['form-text']);

    return $element;
  }

}
