<?php

namespace Drupal\webform_paystack_field\EventSubscriber;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Database\Connection;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Symfony\Component\HttpKernel\Event\RequestEvent;
use Symfony\Component\HttpKernel\KernelEvents;
use Yabacon\Paystack;
use Yabacon\Paystack\Exception\ApiException as PaystackApiException;

/**
 * Event subscriber.
 */
class WebformPaystackFieldInitEventSubscriber implements EventSubscriberInterface {

  /**
   * The database connection.
   *
   * @var \Drupal\Core\Database\Connection
   */
  protected Connection $database;

  /**
   * The config connection.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected ConfigFactoryInterface $configFactory;

  /**
   * Constructs a new Event object.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The database connection.
   * @param \Drupal\Core\Database\Connection $connection
   *   The database connection.   *.
   */
  public function __construct(ConfigFactoryInterface $config_factory, Connection $connection) {
    $this->configFactory = $config_factory;
    $this->database = $connection;
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {

    $events[KernelEvents::REQUEST][] = ['onWebformSubmit'];

    return $events;
  }

  /**
   * {@inheritdoc}
   */
  public function onWebformSubmit(RequestEvent $event) {
    if ($event->getRequest()->get('reference') && $event->getRequest()->get('trxref')) {
      if (!$this->database->select('webform_paystack_trnx', 't')->fields('t', ['webform_id'])->condition('trnx_id', $event->getRequest()->get('reference'))->execute()->fetchField()) {
        $sid = $event->getRequest()->get('reference');
        $webform_object = unserialize($this->database->select('webform_paystack_trnx', 't')->fields('t', ['webform_object'])->condition('trnx_id', $event->getRequest()->get('reference'))->execute()->fetchField(), ['allowed_classes' => FALSE]);
        $currency = '';
        if (isset($webform_object->getData()['currency']) && $webform_object->getData()['currency'] == 'usd') {
          $currency = $webform_object->getData()['currency'] . '_';
        }
        try {
          $paystack = new Paystack($this->configFactory->get('webform_paystack_field.settings')->get($currency . 'webform_paystack_field_private_key'));
          // Initialize a transaction for verify.
          $responseObj = $paystack->transaction->verify([
            'reference' => $sid,
          ]);
        }
        catch (PaystackApiException $e) {
          print_r($e->getMessage());
          die;
        }

        if ($responseObj->data->status == 'success') {
          $webform_object->set('changed', time());
          $webform_object->save();
          $this->database->update('webform_paystack_data')->fields([
            'status' => 1,
            'trxref' => $event->getRequest()->get('trxref'),
            'webform_id' => $webform_object->id(),
          ])->condition('reference',
            $event->getRequest()->get('reference')
          )->execute();
          $this->database->update('webform_paystack_trnx')->fields([
            'webform_id' => $webform_object->id(),
            'webform_object' => NULL,
            'timestamp' => time(),
          ])->condition('trnx_id', $event->getRequest()->get('reference')
            )->execute();
        }
      }
    }
  }

}
