<?php

namespace Drupal\webform_paystack_field\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Paystack settings.
 */
class WebformPaystackFieldSettings extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'webform_paystack_field.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'webform_paystack_field_settings';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('webform_paystack_field.settings');

    $form['webform_paystack_field_setting_naira'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Naira Paystack Currency Setting'),
    ];

    $form['webform_paystack_field_setting_usd'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('USD Paystack Currency Setting'),
    ];
    // Naira.
    $form['webform_paystack_field_setting_naira']['webform_paystack_field_public_key'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Naira Paystack Public Key'),
      '#default_value' => $config->get('webform_paystack_field_public_key') ?? '',
      '#description' => $this->t('Your pubic Key from Paystack. Use test key for test mode and live key for live mode'),
      '#required' => TRUE,
    ];

    $form['webform_paystack_field_setting_naira']['webform_paystack_field_private_key'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Naira Paystack Private Key'),
      '#default_value' => $config->get('webform_paystack_field_private_key') ?? '',
      '#description' => $this->t('Your private Key from Paystack. Use test key for test mode and live key for live mode'),
      '#required' => TRUE,
    ];

    $form['webform_paystack_field_setting_naira']['webform_paystack_field_default_amount'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Naira Default Amount'),
      '#default_value' => $config->get('webform_paystack_field_default_amount') ?? 1000,
      '#description' => $this->t('Default Amount in the Amount Field. Defaults to 1000 Naira'),
    ];

    // USD.
    $form['webform_paystack_field_setting_usd']['usd_webform_paystack_field_public_key'] = [
      '#type' => 'textfield',
      '#title' => $this->t('USD Paystack Public Key'),
      '#default_value' => $config->get('usd_webform_paystack_field_public_key') ?? '',
      '#description' => $this->t('Your pubic Key from Paystack. Use test key for test mode and live key for live mode'),
      '#required' => TRUE,
    ];

    $form['webform_paystack_field_setting_usd']['usd_webform_paystack_field_private_key'] = [
      '#type' => 'textfield',
      '#title' => $this->t('USD Paystack Private Key'),
      '#default_value' => $config->get('usd_webform_paystack_field_private_key') ?? '',
      '#description' => $this->t('Your private Key from Paystack. Use test key for test mode and live key for live mode'),
      '#required' => TRUE,
    ];

    $form['webform_paystack_field_setting_usd']['usd_webform_paystack_field_default_amount'] = [
      '#type' => 'textfield',
      '#title' => $this->t('USD Default Amount'),
      '#default_value' => $config->get('usd_webform_paystack_field_default_amount') ?? 1000,
      '#description' => $this->t('Default Amount in the Amount Field. Defaults to 1000 Naira'),
    ];

    $form['webform_paystack_field_within_website'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Do payment within website(in Paystack PopUp)'),
      '#default_value' => $config->get('webform_paystack_field_within_website') ?? FALSE,
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('webform_paystack_field.settings')
      ->set('webform_paystack_field_public_key', $form_state->getValue('webform_paystack_field_public_key'))
      ->set('webform_paystack_field_private_key', $form_state->getValue('webform_paystack_field_private_key'))
      ->set('webform_paystack_field_default_amount', $form_state->getValue('webform_paystack_field_default_amount'))
      ->set('usd_webform_paystack_field_public_key', $form_state->getValue('usd_webform_paystack_field_public_key'))
      ->set('usd_webform_paystack_field_private_key', $form_state->getValue('usd_webform_paystack_field_private_key'))
      ->set('usd_webform_paystack_field_default_amount', $form_state->getValue('usd_webform_paystack_field_default_amount'))
      ->set('webform_paystack_field_within_website', $form_state->getValue('webform_paystack_field_within_website'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
